# -*- coding: utf-8 -*-


class GetOutError(Exception):
    """Raised when an output can't be returned"""

    pass
